@@ -201,10 +201,10 @@ class superplt():
                     secondposy = minY + 0.83 * (maxY - minY)
                     thirdposy = minY + 0.76 * (maxY - minY)
                     fourthposy = minY + 0.69 * (maxY - minY)
-                plt.text(posx, firstposy, r'$y=ax+b$', fontsize=10)
-                plt.text(posx, secondposy, 'a={:.2uP}'.format(relation.slope) + ' ' + textunit[0], fontsize=10)
-                plt.text(posx, thirdposy, 'b={:.2uP}'.format(relation.intercept) + ' ' + textunit[1], fontsize=10)
-                plt.text(minx, fourthposy, '$R^2$={:.3f}'.format(relation.R2), fontsize=10)
+            plt.text(posx, firstposy, r'$y=ax+b$', fontsize=10)
+            plt.text(posx, secondposy, 'a={:.2uP}'.format(relation.slope) + ' ' + textunit[0], fontsize=10)
+            plt.text(posx, thirdposy, 'b={:.2uP}'.format(relation.intercept) + ' ' + textunit[1], fontsize=10)
+            plt.text(minx, fourthposy, '$R^2$={:.3f}'.format(relation.R2), fontsize=10)
 
 
     def plot_comp(relation, fitxnum=1001, Title=None, pos_leg='right',
@@ -311,6 +311,7 @@ class superplt():
                         secondposy = minY + 0.83 * (maxY - minY)
                         thirdposy = minY + 0.76 * (maxY - minY)
                         fourthposy = minY + 0.69 * (maxY - minY)
+                        posx = minx
                     else:  # 범례가 왼쪽일 때
                         firstposy = minY + 0.31 * (maxY - minY)
                         secondposy = minY + 0.24 * (maxY - minY)
@@ -322,15 +323,16 @@ class superplt():
                         secondposy = minY + 0.24 * (maxY - minY)
                         thirdposy = minY + 0.17 * (maxY - minY)
                         fourthposy = minY + 0.1 * (maxY - minY)
+                        posx = minx
                     else:  # 범례가 왼쪽일 때
                         firstposy = minY + 0.9 * (maxY - minY)
                         secondposy = minY + 0.83 * (maxY - minY)
                         thirdposy = minY + 0.76 * (maxY - minY)
                         fourthposy = minY + 0.69 * (maxY - minY)
-                ax.text(posx, firstposy, r'$y=ax+b$', fontsize=10)
-                ax.text(posx, secondposy, 'a={:.2uP}'.format(relation.slope) + ' ' + textunit[0], fontsize=10)
-                ax.text(posx, thirdposy, 'b={:.2uP}'.format(relation.intercept) + ' ' + textunit[1], fontsize=10)
-                ax.text(minx, fourthposy, '$R^2$={:.3f}'.format(relation.R2), fontsize=10)
+            ax.text(posx, firstposy, r'$y=ax+b$', fontsize=10)
+            ax.text(posx, secondposy, 'a={:.2uP}'.format(relation.slope) + ' ' + textunit[0], fontsize=10)
+            ax.text(posx, thirdposy, 'b={:.2uP}'.format(relation.intercept) + ' ' + textunit[1], fontsize=10)
+            ax.text(posx, fourthposy, '$R^2$={:.3f}'.format(relation.R2), fontsize=10)
 
         # Xlabel 작성
         if Label[0] == 'normal':
